@@ -1,4 +1,5 @@
 import sqlalchemy as sa
+from sqlalchemy.orm.attributes import InstrumentedAttribute
 
 import ckan.model as model
 
@@ -138,7 +139,7 @@ class Authorizer(object):
         
         q = q.filter(sa.or_(*filters))
         return [pr.role for pr in q]
-
+    
     @classmethod
     def is_sysadmin(cls, username):
         user = model.User.by_name(username, autoflush=False)
@@ -171,34 +172,38 @@ class Authorizer(object):
             user = model.User.by_name(username, autoflush=False)
         else:
             user = None
-
+        entity.roles.property.mapper.class_ 
         visitor = model.User.by_name(model.PSEUDO_USER__VISITOR, autoflush=False)
-        logged_in = model.User.by_name(model.PSEUDO_USER__LOGGED_IN, autoflush=False)
-
+        logged_in = model.User.by_name(model.PSEUDO_USER__LOGGED_IN,
+                                       autoflush=False)
         if not cls.is_sysadmin(username):
+            # This gets the role table the entity is joined to. we
+            # need to use this in the queries below as if we use
+            # model.UserObjectRole a cross join happens always
+            # returning all the roles.  
+            role_cls = entity.roles.property.mapper.class_
             q = q.outerjoin('roles')
             if hasattr(entity, 'state'):
                 state = entity.state
             else:
-                state = model.State.ACTIVE
+                state = None
                 
             filters = [model.UserObjectRole.user==visitor]
             for authz_group in cls.get_authorization_groups(username):
-                filters.append(model.UserObjectRole.authorized_group==authz_group)
-                
+                filters.append(role_cls.authorized_group==authz_group)
             if user:
-                filters.append(model.UserObjectRole.user==user)
-                filters.append(model.UserObjectRole.user==logged_in)
+                filters.append(role_cls.user==user)
+                filters.append(role_cls.user==logged_in)
                 q = q.filter(sa.or_(
-                    sa.and_(model.UserObjectRole.role==model.RoleAction.role,
+                    sa.and_(role_cls.role==model.RoleAction.role,
                             model.RoleAction.action==action,
-                            state==model.State.ACTIVE),
-                    model.UserObjectRole.role==model.Role.ADMIN))
+                            state and state==model.State.ACTIVE),
+                    role_cls.role==model.Role.ADMIN))
             else:
                 q = q.filter(
-                    sa.and_(model.UserObjectRole.role==model.RoleAction.role,
+                    sa.and_(role_cls.role==model.RoleAction.role,
                             model.RoleAction.action==action,
-                            state==model.State.ACTIVE),
+                            state and state==model.State.ACTIVE),
                     )
             q = q.filter(sa.or_(*filters))   
             q = q.distinct()
