@@ -1,5 +1,6 @@
 import logging
 import urlparse
+from urllib import urlencode
 
 from sqlalchemy.orm import eagerload_all
 from sqlalchemy import or_
@@ -11,7 +12,7 @@ from ckan.lib.base import *
 from ckan.lib.search import query_for, QueryOptions, SearchError
 from ckan.lib.cache import proxy_cache
 from ckan.lib.package_saver import PackageSaver, ValidationException
-from ckan.plugins import ExtensionPoint, IPackageController
+from ckan.plugins import PluginImplementations, IPackageController
 import ckan.forms
 import ckan.authz
 import ckan.rating
@@ -19,71 +20,82 @@ import ckan.misc
 
 logger = logging.getLogger('ckan.controllers')
 
+def search_url(params):
+    url = h.url_for(controller='package', action='search')
+    params = [(k, v.encode('utf-8') if isinstance(v, basestring) else str(v)) \
+                    for k, v in params]
+    return url + u'?' + urlencode(params)
+
 class PackageController(BaseController):
     authorizer = ckan.authz.Authorizer()
-    extensions = ExtensionPoint(IPackageController)
-
-    def index(self):
-        query = ckan.authz.Authorizer().authorized_query(c.user, model.Package)
-        c.package_count = query.count()
-        return render('package/index.html')
-
-    @proxy_cache()
-    def list(self):
-        query = ckan.authz.Authorizer().authorized_query(c.user, model.Package)
-        query = query.options(eagerload_all('package_tags.tag'))
-        query = query.options(eagerload_all('package_resources_all'))
-        c.page = h.AlphaPage(
-            collection=query,
-            page=request.params.get('page', 'A'),
-            alpha_attribute='title',
-            other_text=_('Other'),
-        )
-        return render('package/list.html')
+    extensions = PluginImplementations(IPackageController)
 
     def search(self):        
-        c.q = request.params.get('q') # unicode format (decoded from utf8)
+        q = c.q = request.params.get('q') # unicode format (decoded from utf8)
         c.open_only = request.params.get('open_only')
         c.downloadable_only = request.params.get('downloadable_only')
-        if c.q:
-            c.query_error = False
+        if c.q is None or len(c.q.strip()) == 0:
+            q = '*:*'
+        c.query_error = False
+        try:
             page = int(request.params.get('page', 1))
-            limit = 20
-            query = query_for(model.Package)
-            try:
-                query.run(query=c.q,
-                          limit=limit,
-                          offset=(page-1)*limit,
-                          return_objects=True,
-                          filter_by_openness=c.open_only,
-                          filter_by_downloadable=c.downloadable_only,
-                          username=c.user)
-            
-                c.page = h.Page(
-                    collection=query.results,
-                    page=page,
-                    item_count=query.count,
-                    items_per_page=limit
-                )
-                c.page.items = query.results
-            except SearchError, se:
-                c.query_error = True
-                c.page = h.Page(collection=[])
-            
-            # tag search
-            c.tag_limit = 25
-            query = query_for('tag', backend='sql')
-            try:
-                query.run(query=c.q,
-                          return_objects=True,
-                          limit=c.tag_limit,
-                          username=c.user)
-                c.tags = query.results
-                c.tags_count = query.count
-            except SearchError, se:
-                c.tags = []
-                c.tags_count = 0
+        except ValueError, e:
+            abort(400, ('"page" parameter must be an integer'))
+        limit = 20
+        query = query_for(model.Package)
 
+        # most search operations should reset the page counter:
+        params_nopage = [(k, v) for k,v in request.params.items() if k != 'page']
+        
+        def drill_down_url(**by):
+            params = list(params_nopage)
+            params.extend(by.items())
+            return search_url(set(params))
+        
+        c.drill_down_url = drill_down_url 
+        
+        def remove_field(key, value):
+            params = list(params_nopage)
+            params.remove((key, value))
+            return search_url(params)
+
+        c.remove_field = remove_field
+        
+        def pager_url(q=None, page=None):
+            params = list(params_nopage)
+            params.append(('page', page))
+            return search_url(params)
+
+        try:
+            c.fields = []
+            for (param, value) in request.params.items():
+                if not param in ['q', 'open_only', 'downloadable_only', 'page'] and len(value):
+                    c.fields.append((param, value))
+
+            query.run(query=q,
+                      fields=c.fields,
+                      facet_by=g.facets,
+                      limit=limit,
+                      offset=(page-1)*limit,
+                      return_objects=True,
+                      filter_by_openness=c.open_only,
+                      filter_by_downloadable=c.downloadable_only,
+                      username=c.user)
+                       
+            c.page = h.Page(
+                collection=query.results,
+                page=page,
+                url=pager_url,
+                item_count=query.count,
+                items_per_page=limit
+            )
+            c.facets = query.facets
+            c.page.items = query.results
+        except SearchError, se:
+            c.query_error = True
+            c.facets = {}
+            c.page = h.Page(collection=[])
+        
         return render('package/search.html')
 
     @staticmethod
@@ -91,20 +103,26 @@ class PackageController(BaseController):
         # note: we need pkg.id in addition to pkg.revision.id because a
         # revision may have more than one package in it.
         return str(hash((pkg.id, pkg.latest_related_revision.id, c.user, pkg.get_average_rating())))
-        
+
     def _clear_pkg_cache(self, pkg):
         read_cache = cache.get_cache('package/read.html', type='dbm')
         read_cache.remove_value(self._pkg_cache_key(pkg))
 
     @proxy_cache()
     def read(self, id):
+        
+        #check if package exists
         c.pkg = model.Package.get(id)
         if c.pkg is None:
             abort(404, gettext('Package not found'))
         
-        cache_key = self._pkg_cache_key(c.pkg)
+        cache_key = self._pkg_cache_key(c.pkg)        
         etag_cache(cache_key)
         
+        #set a cookie so we know whether to display the welcome message
+        c.hide_welcome_message = bool(request.cookies.get('hide_welcome_message', False))
+        response.set_cookie('hide_welcome_message', '1', max_age=3600) #(make cross-site?)
+
         # used by disqus plugin
         c.current_package_id = c.pkg.id
         
@@ -115,16 +133,41 @@ class PackageController(BaseController):
                 rdf_url = '%s%s' % (config['rdf_packages'], c.pkg.name)
                 redirect(rdf_url, code=303)
 
+        #is the user allowed to see this package?
         auth_for_read = self.authorizer.am_authorized(c, model.Action.READ, c.pkg)
         if not auth_for_read:
-            abort(401, str(gettext('Unauthorized to read package %s') % id))
+            abort(401, gettext('Unauthorized to read package %s') % id)
         
         for item in self.extensions:
             item.read(c.pkg)
 
+        #render the package
         PackageSaver().render_package(c.pkg)
         return render('package/read.html')
 
+    def comments(self, id):
+
+        #check if package exists
+        c.pkg = model.Package.get(id)
+        if c.pkg is None:
+            abort(404, gettext('Package not found'))
+
+        # used by disqus plugin
+        c.current_package_id = c.pkg.id
+
+        #is the user allowed to see this package?
+        auth_for_read = self.authorizer.am_authorized(c, model.Action.READ, c.pkg)
+        if not auth_for_read:
+            abort(401, gettext('Unauthorized to read package %s') % id)
+
+        for item in self.extensions:
+            item.read(c.pkg)
+
+        #render the package
+        PackageSaver().render_package(c.pkg)
+        return render('package/comments.html')
+
+
     def history(self, id):
         if 'diff' in request.params or 'selected1' in request.params:
             try:
@@ -193,7 +236,7 @@ class PackageController(BaseController):
         # Check access control for user to create a package.
         auth_for_create = self.authorizer.am_authorized(c, model.Action.PACKAGE_CREATE, model.System())
         if not auth_for_create:
-            abort(401, str(gettext('Unauthorized to create a package')))
+            abort(401, gettext('Unauthorized to create a package'))
         # Get the name of the package form.
         fs = self._get_package_fieldset(is_admin=is_admin)
         if 'save' in request.params or 'preview' in request.params:
@@ -204,7 +247,7 @@ class PackageController(BaseController):
         if request.params.has_key('save'):
             fs = fs.bind(record, data=dict(request.params) or None, session=model.Session)
             try:
-                PackageSaver().commit_pkg(fs, None, None, log_message, c.author, client=c)
+                PackageSaver().commit_pkg(fs, log_message, c.author, client=c)
                 pkgname = fs.name.value
 
                 pkg = model.Package.by_name(pkgname)
@@ -245,7 +288,7 @@ class PackageController(BaseController):
         c.form = self._render_edit_form(fs, request.params, clear_session=True)
         if 'preview' in request.params:
             try:
-                PackageSaver().render_preview(fs, id, record.id,
+                PackageSaver().render_preview(fs,
                                               log_message=log_message,
                                               author=c.author, client=c)
                 c.preview = h.literal(render('package/read_core.html'))
@@ -262,9 +305,10 @@ class PackageController(BaseController):
         c.pkg = pkg = model.Package.get(id)
         if pkg is None:
             abort(404, '404 Not Found')
+        model.Session().autoflush = False
         am_authz = self.authorizer.am_authorized(c, model.Action.EDIT, pkg)
         if not am_authz:
-            abort(401, str(gettext('User %r not authorized to edit %s') % (c.user, id)))
+            abort(401, gettext('User %r not authorized to edit %s') % (c.user, id))
 
         auth_for_change_state = self.authorizer.am_authorized(c, model.Action.CHANGE_STATE, pkg)
         fs = self._get_package_fieldset(is_admin=auth_for_change_state)
@@ -291,14 +335,14 @@ class PackageController(BaseController):
             try:
                 for item in self.extensions:
                     item.edit(fs.model)
-                PackageSaver().commit_pkg(fs, id, pkg.id, log_message, c.author, client=c)
+                PackageSaver().commit_pkg(fs, log_message, c.author, client=c)
                 # do not use package name from id, as it may have been edited
                 pkgname = fs.name.value
                 self._form_save_redirect(pkgname, 'edit')
             except ValidationException, error:
                 fs = error.args[0]
                 c.form = self._render_edit_form(fs, request.params,
-                        clear_session=True)
+                                                clear_session=True)
                 return render('package/edit.html')
             except KeyError, error:
                 abort(400, 'Missing parameter: %s' % error.args)
@@ -309,7 +353,7 @@ class PackageController(BaseController):
                 self._adjust_license_id_options(pkg, fs)
             fs = fs.bind(pkg, data=dict(request.params))
             try:
-                PackageSaver().render_preview(fs, id, pkg.id,
+                PackageSaver().render_preview(fs,
                                               log_message=log_message,
                                               author=c.author, client=c)
                 c.pkgname = fs.name.value
@@ -359,11 +403,11 @@ class PackageController(BaseController):
 
         c.authz_editable = self.authorizer.am_authorized(c, model.Action.EDIT_PERMISSIONS, pkg)
         if not c.authz_editable:
-            abort(401, str(gettext('User %r not authorized to edit %s authorizations') % (c.user, id)))
+            abort(401, gettext('User %r not authorized to edit %s authorizations') % (c.user, id))
 
         if 'save' in request.params: # form posted
-            # needed because request is nested
-            # multidict which is read only
+            # A dict needed for the params because request.params is a nested
+            # multidict, which is read only.
             params = dict(request.params)
             c.fs = ckan.forms.get_authz_fieldset('package_authz_fs').bind(pkg.roles, data=params or None)
             try:
@@ -468,11 +512,27 @@ class PackageController(BaseController):
     def _render_edit_form(self, fs, params={}, clear_session=False):
         # errors arrive in c.error and fs.errors
         c.log_message = params.get('log_message', '')
-        # expunge everything from session so we don't have any problematic
-        # saves (this gets called on validation exceptions a lot)
-        # Todo: Explain why there are 'saves' when rendering a form.
+        # rgrp: expunge everything from session before dealing with
+        # validation errors) so we don't have any problematic saves
+        # when the fs.render causes a flush.
+        # seb: If the session is *expunged*, then the form can't be
+        # rendered; I've settled with a rollback for now, which isn't
+        # necessarily what's wanted here.
+        # dread: I think this only happened with tags because until
+        # this changeset, Tag objects were created in the Renderer
+        # every time you hit preview. So I don't believe we need to
+        # clear the session any more. Just in case I'm leaving it in
+        # with the log comments to find out.
         if clear_session:
-            model.Session.clear()
+            # log to see if clearing the session is ever required
+            if model.Session.new or model.Session.dirty or model.Session.deleted:
+                log.warn('Expunging session changes which were not expected: '
+                         '%r %r %r', (model.Session.new, model.Session.dirty,
+                                      model.Session.deleted))
+            try:
+                model.Session.rollback()
+            except AttributeError: # older SQLAlchemy versions
+                model.Session.clear()
         edit_form_html = fs.render()
         c.form = h.literal(edit_form_html)
         return h.literal(render('package/edit_form.html'))
