@@ -1,8 +1,11 @@
 from pylons.i18n import _
+from pylons import config
+from sqlalchemy.orm import eagerload_all
 
 from ckan.lib.base import *
 from ckan.lib.search import query_for
-from ckan.lib.helpers import json, AlphaPage, Page
+from ckan.lib.cache import proxy_cache
+from ckan.lib.helpers import AlphaPage, Page
 
 LIMIT = 25
 
@@ -37,32 +40,15 @@ class TagController(BaseController):
            
         return render('tag/index.html')
 
+    @proxy_cache()
     def read(self, id):
-        c.tag = model.Tag.by_name(id)
+        query = model.Session.query(model.Tag)
+        query = query.filter(model.Tag.name==id)
+        query = query.options(eagerload_all('package_tags.package'))
+        query = query.options(eagerload_all('package_tags.package.package_tags.tag'))
+        query = query.options(eagerload_all('package_tags.package.package_resources_all'))
+        c.tag = query.first()
         if c.tag is None:
             abort(404)
         return render('tag/read.html')
 
-    def autocomplete(self):
-        incomplete = request.params.get('incomplete', '')
-        if incomplete:
-            query = query_for('tag', backend='sql')
-            query.run(query=incomplete,
-                      return_objects=True,
-                      limit=10,
-                      username=c.user)
-            tagNames = [t.name for t in query.results]
-        else:
-            tagNames = []
-        resultSet = {
-            "ResultSet": {
-                "Result": []
-            }
-        }
-        for tagName in tagNames[:10]:
-            result = {
-                "Name": tagName
-            }
-            resultSet["ResultSet"]["Result"].append(result)
-        return json.dumps(resultSet)
-
