@@ -2,22 +2,27 @@
 
 Provides the BaseController class for subclassing.
 """
+from datetime import datetime
+from hashlib import md5
 import logging
+import os
 
+from paste.deploy.converters import asbool
 from pylons import c, cache, config, g, request, response, session
 from pylons.controllers import WSGIController
-from pylons.controllers.util import abort, etag_cache, redirect_to, redirect
+from pylons.controllers.util import abort as _abort
+from pylons.controllers.util import etag_cache, redirect_to, redirect
 from pylons.decorators import jsonify, validate
 from pylons.i18n import _, ungettext, N_, gettext
 from pylons.templating import cached_template, pylons_globals
+from genshi.template import MarkupTemplate
 from webhelpers.html import literal
 
 import ckan
 import ckan.lib.helpers as h
-from ckan.plugins import ExtensionPoint, IGenshiStreamFilter
+from ckan.plugins import PluginImplementations, IGenshiStreamFilter
 from ckan.lib.helpers import json
 import ckan.model as model
-import os
 
 # nuke cache
 #from pylons import cache
@@ -30,18 +35,26 @@ APIKEY_HEADER_NAME_DEFAULT = 'X-CKAN-API-Key'
 
 ALLOWED_FIELDSET_PARAMS = ['package_form', 'restrict']
 
+def abort(status_code=None, detail='', headers=None, comment=None):
+    if detail:
+        h.flash_error(detail)
+    return _abort(status_code=status_code, 
+                  detail=detail, 
+                  headers=headers, 
+                  comment=comment)
 
 def render(template_name, extra_vars=None, cache_key=None, cache_type=None, 
-           cache_expire=None, method='xhtml'):
+           cache_expire=None, method='xhtml', loader_class=MarkupTemplate):
     
     def render_template():
         globs = extra_vars or {}
         globs.update(pylons_globals())
         globs['actions'] = model.Action
-        template = globs['app_globals'].genshi_loader.load(template_name)
+        template = globs['app_globals'].genshi_loader.load(template_name,
+            cls=loader_class)
         stream = template.generate(**globs)
         
-        for item in ExtensionPoint(IGenshiStreamFilter):
+        for item in PluginImplementations(IGenshiStreamFilter):
             stream = item.filter(stream)
         
         return literal(stream.render(method=method, encoding=None))
@@ -67,7 +80,8 @@ class BaseController(WSGIController):
     log = logging.getLogger(__name__)
 
     def __before__(self, action, **params):
-        self._start_call_timing()
+        c.time_call_started = datetime.now()
+
         # what is different between session['user'] and environ['REMOTE_USER']
         c.__version__ = ckan.__version__
         c.user = request.environ.get('REMOTE_USER', None)
@@ -94,7 +108,7 @@ class BaseController(WSGIController):
             model.Session.remove()
 
     def __after__(self, action, **params):
-        self._stop_call_timing()
+        c.time_call_stopped = datetime.now()
         self._write_call_timing()
 
     def _get_user(self, reference):
@@ -128,6 +142,8 @@ class BaseController(WSGIController):
         return request_data
         
     def _make_unicode(self, entity):
+        """Cast bare strings and strings in lists or dicts to Unicode
+        """
         if isinstance(entity, str):
             return unicode(entity)
         elif isinstance(entity, list):
@@ -164,14 +180,8 @@ class BaseController(WSGIController):
         user = query.filter_by(apikey=apikey).first()
         return user
 
-    def _start_call_timing(self):
-        c.time_call_started = self._get_now_time()
-
-    def _stop_call_timing(self):
-        c.time_call_stopped = self._get_now_time()
-        
     def _write_call_timing(self):
-        if config.get('ckan.enable_call_timing', None):
+        if asbool(config.get('ckan.enable_call_timing', "False")):
             call_duration = c.time_call_stopped - c.time_call_started
             timing_data = {
                 "path": request.path, 
@@ -179,29 +189,23 @@ class BaseController(WSGIController):
                 "duration": str(call_duration),
             }
             timing_msg = json.dumps(timing_data)
-            timing_cache_path = self._get_timing_cache_path()
             timing_file_path = os.path.join(timing_cache_path, c.time_call_started.isoformat())
             timing_file = file(timing_file_path, 'w')
             timing_file.write(timing_msg)
             timing_file.close()
 
-    def _get_now_time(self):
-        import datetime
-        return datetime.datetime.now()
-
     def _get_timing_cache_path(self):
-        path = os.path.join(config['pylons.cache_dir'], 'call_timing')
-        if not os.path.exists(path):
-             os.makedirs(path)
+
         return path
 
-    def _get_user_editable_groups(self): 
+    @classmethod
+    def _get_user_editable_groups(cls): 
         if not hasattr(c, 'user'):
             c.user = model.PSEUDO_USER__VISITOR
         import ckan.authz # Todo: Move import to top of this file?
         groups = ckan.authz.Authorizer.authorized_query(c.user, model.Group, 
             action=model.Action.EDIT).all()
-        return groups
+        return [g for g in groups if g.state==model.State.ACTIVE] 
 
     def _get_package_dict(self, *args, **kwds):
         import ckan.forms
@@ -216,12 +220,10 @@ class BaseController(WSGIController):
         import ckan.forms
         return ckan.forms.edit_package_dict(*args, **kwds)
 
-    def _get_package_fieldset(self, is_admin=False):
-        kwds= {}
-        for key in request.params:
-            if key in ALLOWED_FIELDSET_PARAMS:
-                kwds[key] = request.params[key]
-        kwds['user_editable_groups'] = self._get_user_editable_groups()
+    @classmethod
+    def _get_package_fieldset(cls, is_admin=False, **kwds):
+        kwds.update(request.params)
+        kwds['user_editable_groups'] = cls._get_user_editable_groups()
         kwds['is_admin'] = is_admin
         from ckan.forms import GetPackageFieldset
         return GetPackageFieldset(**kwds).fieldset
