@@ -2,13 +2,14 @@ from sqlalchemy import *
 from migrate import *
 import migrate.changeset
 
-metadata = MetaData(migrate_engine)
+metadata = MetaData()
 
-def upgrade():
+def upgrade(migrate_engine):
+    metadata.bind = migrate_engine
     package_resource = Table('package_resource', metadata, autoload=True)
     column = Column('hash', UnicodeText)
     column.create(package_resource)
 
-def downgrade():
+def downgrade(migrate_engine):
     raise NotImplementedError()
 
