@@ -2,7 +2,7 @@ from sqlalchemy import *
 from migrate import *
 import datetime
 
-metadata = MetaData(migrate_engine)
+metadata = MetaData()
 
 harvested_document_table = Table('harvested_document', metadata,
         Column('id', UnicodeText, primary_key=True),
@@ -11,9 +11,11 @@ harvested_document_table = Table('harvested_document', metadata,
         Column('content', UnicodeText, nullable=False),
 )
 
-def upgrade():
+def upgrade(migrate_engine):
+    metadata.bind = migrate_engine
     harvested_document_table.create()
 
-def downgrade():
+def downgrade(migrate_engine):
+    metadata.bind = migrate_engine
     harvested_document_table.drop()
 
