@@ -6,7 +6,6 @@ from ckan.tests.pylons_controller import PylonsTestCase
 class TestGroupFieldset(PylonsTestCase):
     @classmethod
     def setup_class(self):
-        model.Session.remove()
         ckan.tests.CreateTestData.create()
 
     @classmethod
@@ -17,10 +16,11 @@ class TestGroupFieldset(PylonsTestCase):
         group = model.Group.by_name(u'roger')
         fs = ckan.forms.get_group_fieldset().bind(group)
         out = fs.render()
+        assert 'Name' in out
+        assert '*' in out
+        assert 'Title' in out
         desc = fs.description.render()
         assert 'textarea' in desc, desc
-        # TODO: ...
-        # assert 'checkbox' in out, out
-        # assert 'select' in out, out
+        assert 'Roger likes these books' in desc, desc
 
 
