@@ -1,19 +1,11 @@
+from paste.deploy.converters import asbool
 from ckan.tests.functional.api.base import *
+from ckan.lib.create_test_data import CreateTestData
+from ckan.tests import is_search_supported
+from ckan.tests import TestController as ControllerTestCase
 
 class ModelApiTestCase(BaseModelApiTestCase):
 
-    @classmethod
-    def setup_class(self):
-        model.Session.remove()
-        model.repo.rebuild_db()
-        model.Session.remove()
-
-    @classmethod
-    def teardown_class(self):
-        model.Session.remove()
-        model.repo.rebuild_db()
-        model.Session.remove()
-
     def setup(self):
         self.create_common_fixtures()
         self.init_extra_environ()
@@ -29,29 +21,7 @@ class ModelApiTestCase(BaseModelApiTestCase):
         self.job3 = None
 
     def teardown(self):
-        self.rebuild() 
-        return
-#        if self.job:
-#            self.delete_commit(self.job)
-#        if self.job1:
-#            self.delete_commit(self.job1)
-#        if self.job2:
-#            self.delete_commit(self.job2)
-#        if self.job3:
-#            self.delete_commit(self.job3)
-#        if self.source:
-#            self.delete_commit(self.source)
-#        if self.source1:
-#            self.delete_commit(self.source1)
-#        if self.source2:
-#            self.delete_commit(self.source2)
-#        if self.source3:
-#            self.delete_commit(self.source3)
-#        if self.source4:
-#            self.delete_commit(self.source4)
-#        if self.source5:
-#            self.delete_commit(self.source5)
-#        self.delete_common_fixtures()
+        model.repo.rebuild_db()
 
     def test_02_get_tag_register_ok(self):
         # Test Packages Register Get 200.
@@ -95,10 +65,10 @@ class ModelApiTestCase(BaseModelApiTestCase):
         res = self.app.post(offset, params=postparams, status=200,
                 extra_environ=self.extra_environ)
         model.Session.remove()
+        rev = model.repo.new_revision()
         group = model.Group.by_name(self.testgroupvalues['name'])
         assert group
         model.setup_default_user_roles(group, [self.user])
-        rev = model.repo.new_revision()
         model.repo.commit_and_remove()
         group = model.Group.by_name(self.testgroupvalues['name'])
         assert group
@@ -208,10 +178,10 @@ class ModelApiTestCase(BaseModelApiTestCase):
     def test_10_edit_group_name_duplicate(self):
         # create a group with testgroupvalues
         if not model.Group.by_name(self.testgroupvalues['name']):
+            rev = model.repo.new_revision()
             group = model.Group()
             model.Session.add(group)
             group.name = self.testgroupvalues['name']
-            rev = model.repo.new_revision()
             model.Session.commit()
 
             group = model.Group.by_name(self.testgroupvalues['name'])
@@ -223,10 +193,10 @@ class ModelApiTestCase(BaseModelApiTestCase):
         # create a group with name 'dupname'
         dupname = u'dupname'
         if not model.Group.by_name(dupname):
+            rev = model.repo.new_revision()
             group = model.Group()
             model.Session.add(group)
             group.name = dupname
-            rev = model.repo.new_revision()
             model.Session.commit()
         assert model.Group.by_name(dupname)
 
@@ -244,15 +214,15 @@ class ModelApiTestCase(BaseModelApiTestCase):
         # create a group with testgroupvalues
         group = model.Group.by_name(self.testgroupvalues['name'])
         if not group:
+            rev = model.repo.new_revision()
             group = model.Group()
             model.Session.add(group)
             group.name = self.testgroupvalues['name']
-            rev = model.repo.new_revision()
             model.repo.commit_and_remove()
 
+            rev = model.repo.new_revision()
             group = model.Group.by_name(self.testgroupvalues['name'])
             model.setup_default_user_roles(group, [self.user])
-            rev = model.repo.new_revision()
             model.repo.commit_and_remove()
         assert group
         user = model.User.by_name(self.user_name)
@@ -353,8 +323,7 @@ class ModelApiTestCase(BaseModelApiTestCase):
             assert license['url'] == license.url
 
 
-# Note well, relationships are actually part of the Model API.
-class RelationshipsApiTestCase(ApiControllerTestCase):
+class RelationshipsApiTestCase(ApiTestCase, ControllerTestCase):
 
     @classmethod
     def setup_class(self):
@@ -372,6 +341,7 @@ class RelationshipsApiTestCase(ApiControllerTestCase):
     def teardown(self):
         for relationship in self.anna.get_relationships():
             relationship.purge()
+        model.Session.commit()
         relationships = self.anna.get_relationships()
         assert relationships == [], "There are still some relationships: %s" % relationships
 
@@ -566,11 +536,14 @@ class RelationshipsApiTestCase(ApiControllerTestCase):
         assert rel_dict['type'] == type, (rel_dict, type)
         assert rel_dict['comment'] == comment, (rel_dict, comment)
 
-# Todo: Rename to PackageSearchApiTestCase.
-class PackageSearchApiTestCase(ApiControllerTestCase):
+
+class PackageSearchApiTestCase(ApiTestCase, ControllerTestCase):
 
     @classmethod
     def setup_class(self):
+        if not is_search_supported():
+            import nose
+            raise nose.SkipTest
         indexer = TestSearchIndexer()
         CreateTestData.create()
         self.package_fixture_data = {
@@ -830,7 +803,7 @@ class PackageSearchApiTestCase(ApiControllerTestCase):
         assert t == datetime.datetime(2012, 3, 4, 5, 6, 7, 890123), t
 
 
-class ResourceSearchApiTestCase(ApiControllerTestCase):
+class ResourceSearchApiTestCase(ApiTestCase, ControllerTestCase):
 
     @classmethod
     def setup_class(self):
@@ -903,10 +876,10 @@ class ResourceSearchApiTestCase(ApiControllerTestCase):
         assert 'package_id' in result.body, result.body
 
 
-class QosApiTestCase(ApiControllerTestCase):
+class QosApiTestCase(ApiTestCase, ControllerTestCase):
 
     def test_throughput(self):
-        if not config.get('ckan.enable_call_timing', None):
+        if not asbool(config.get('ckan.enable_call_timing', "false")):
             raise SkipTest
         # Create some throughput.
         import datetime
@@ -922,7 +895,7 @@ class QosApiTestCase(ApiControllerTestCase):
         assert throughput > 1, throughput
  
 
-class MiscApiTestCase(ApiControllerTestCase):
+class MiscApiTestCase(ApiTestCase, ControllerTestCase):
 
     @classmethod
     def setup_class(self):
@@ -930,6 +903,7 @@ class MiscApiTestCase(ApiControllerTestCase):
             CreateTestData.delete()
         except:
             pass
+        model.repo.init_db()
         model.Session.remove()
         CreateTestData.create()
 
@@ -956,8 +930,8 @@ class TestModelApi1(Api1TestCase, ModelApiTestCase):
             }
         offset = self.package_offset()
         postparams = '%s=1' % self.dumps(test_params)
-        res = self.app.post(offset, params=postparams, status=[200],
-                extra_environ=self.extra_environ)
+        res = self.app.post(offset, params=postparams, 
+                            extra_environ=self.extra_environ)
         model.Session.remove()
         pkg = self.get_package_by_name(test_params['name'])
         assert pkg
