@@ -50,6 +50,7 @@ class TestRead(TestPackageBase):
 class TestEdit(TestPackageBase):
     @classmethod
     def setup_class(self):
+        model.repo.init_db()
         model.Session.add(model.User(name=u'testadmin'))
         model.repo.commit_and_remove()
 
@@ -58,7 +59,6 @@ class TestEdit(TestPackageBase):
         model.Session.remove()
         model.repo.rebuild_db()
 
-
     def test_edit_bad_name(self):
         init_data = [{'name':'edittest',
                       'url':'testurl',
@@ -398,15 +398,19 @@ class TestEdit(TestPackageBase):
 class TestNew(TestPackageBase):
     pkgname = u'testpkg'
 
+    @classmethod
+    def setup_class(self):
+        CreateTestData.create()        
+
     @classmethod
     def teardown_class(self):
-        model.Session.remove()
         pkg = model.Package.by_name(self.pkgname)
         if pkg:
             pkg.purge()
         model.Session.commit()
         model.Session.remove()
-
+        model.repo.rebuild_db()
+        
     def test_new_simple(self):
         # new package
         prefix = 'Package--'
