@@ -1,4 +1,5 @@
 from ckan.tests import *
+from ckan.tests import is_search_supported
 import ckan.lib.search as search
 from ckan import plugins
 from test_package_search import TestSearchOverall
@@ -9,6 +10,9 @@ class TestSearchOverallWithSynchronousIndexing(TestSearchOverall):
 
     @classmethod
     def setup_class(self):
+        if not is_search_supported():
+            raise SkipTest("Search not supported")
+
         import gc
         from pylons import config
 
